@@ -392,7 +392,6 @@ handle_internet_request (int ls)
     int s;
     size_t addrlen = sizeof (struct sockaddr_in);
     struct sockaddr_in peer;	/* for peer socket address */
-    char addrstr[addrlen];
     pid_t pid;
 
     memset ((char *) &peer, 0, sizeof (struct sockaddr_in));
@@ -402,24 +401,21 @@ handle_internet_request (int ls)
 	exit (1);
     }
 
-    /* TODO: Check errno. */
-    inet_ntop (AF_INET, &peer, addrstr, addrlen);
-
     if (verbose_output)
 	syslog_message (LOG_INFO, "Connection was made from %s port %u.",
-			addrstr, ntohs (peer.sin_port));
+			inet_ntoa (peer.sin_addr), ntohs (peer.sin_port));
 
     /* Check that access is allowed - if not return crud to the client */
     if (!permitted (peer.sin_addr.s_addr, s)) {
 	close (s);
 	syslog_message (LOG_CRIT, "Refused connection from %s.",
-			addrstr);
+			inet_ntoa (peer.sin_addr));
 	return;
     }			/* if */
 
     if (verbose_output)
 	syslog_message (LOG_INFO, "Accepted connection from %s port %u.",
-			addrstr, ntohs (peer.sin_port));
+			inet_ntoa (peer.sin_addr), ntohs (peer.sin_port));
 
     pid = fork ();
 
@@ -440,7 +436,7 @@ handle_internet_request (int ls)
 
     if (verbose_output)
 	syslog_message (LOG_INFO, "Closed connection to %s port %u.",
-			addrstr, ntohs (peer.sin_port));
+			inet_ntoa (peer.sin_addr), ntohs (peer.sin_port));
 
     _exit (0);
 }				/* handle_internet_request */
@@ -564,7 +560,6 @@ main (int argc, char **argv)
     if (invoked_from_inetd) {
 	size_t addrlen = sizeof (struct sockaddr_in);
 	struct sockaddr_in peer;
-	char addrstr[addrlen];
 
 	memset ((char *) &peer, 0, sizeof (struct sockaddr_in));
 
@@ -573,18 +568,15 @@ main (int argc, char **argv)
 	    exit (1);
 	}
 
-	/* TODO: Check errno. */
-	inet_ntop (AF_INET, &peer, addrstr, addrlen);
-
 	if (verbose_output)
 	    syslog_message (LOG_INFO, "Connection was made from %s port %u.",
-			    addrstr, ntohs (peer.sin_port));
+			    inet_ntoa (peer.sin_addr), ntohs (peer.sin_port));
 
 	/* Check that access is allowed - if not return crud to the client */
 	if (!permitted (peer.sin_addr.s_addr, 0)) {
 	    close (0);
 	    syslog_message (LOG_CRIT, "Refused connection from %s.",
-			    addrstr);
+			    inet_ntoa (peer.sin_addr));
 	    exit (1);
 	}
 
