@@ -58,6 +58,15 @@
 #endif
 #undef _KERNEL
 
+
+#if (__FreeBSD_version >= 1101001)
+#define _KERNEL
+#include <ufs/ufs/extattr.h>
+#include <ufs/ufs/ufsmount.h>
+#undef _KERNEL
+#endif
+
+
 #include <sys/ucred.h>
 #include <sys/sysctl.h>
 
@@ -91,9 +100,9 @@ _glibtop_sysdeps_freebsd_dev_inode (glibtop *server, struct vnode *vnode,
         *inum = 0;
         *dev = 0;
 
-        if (kvm_read (server->machine.kd, (gulong) &vnode->v_tag,
+        if (kvm_read (server->machine->kd, (gulong) &vnode->v_tag,
  	             (char *) &tagptr, sizeof (tagptr)) != sizeof (tagptr) ||
-            kvm_read (server->machine.kd, (gulong) tagptr,
+            kvm_read (server->machine->kd, (gulong) tagptr,
 		     (char *) tagstr, sizeof (tagstr)) != sizeof (tagstr))
         {
                 glibtop_warn_io_r (server, "kvm_read (tagptr)");
@@ -111,7 +120,7 @@ _glibtop_sysdeps_freebsd_dev_inode (glibtop *server, struct vnode *vnode,
                 return;
         }
 
-        if (kvm_read (server->machine.kd, (gulong) VTOI(vn), (char *) &inode,
+        if (kvm_read (server->machine->kd, (gulong) VTOI(vn), (char *) &inode,
  	              sizeof (inode)) != sizeof (inode))
         {
                 glibtop_warn_io_r (server, "kvm_read (inode)");
@@ -151,7 +160,7 @@ _glibtop_sysdeps_freebsd_dev_inode (glibtop *server, struct vnode *vnode,
 
                 struct my_zfsvfs zvfs;
 
-                if (kvm_read(server->machine.kd,
+                if (kvm_read(server->machine->kd,
                              (unsigned long)(znode->z_zfsvfs),
                              &zvfs, sizeof zvfs) != sizeof zvfs) {
                         glibtop_warn_io_r(server, "kvm_read (z_zfsvfs)");
@@ -166,13 +175,39 @@ _glibtop_sysdeps_freebsd_dev_inode (glibtop *server, struct vnode *vnode,
                 *inum = inode.i_number;
 
 
+#if (__FreeBSD_version >= 1101001)
+/*
+  The ufs struct inode changed between 11.0 and 11.1.
+
+  commit 20f1e8ac63b58708989267ea34a6aefa90b46577
+  Author: kib <kib@FreeBSD.org>
+  Date:   Sat Sep 17 16:47:34 2016 +0000
+
+  Reduce size of ufs inode.
+  [...]
+*/
+		struct ufsmount um;
+
+		if (kvm_read(server->machine->kd, (gulong)inode.i_ump, &um, sizeof um) != sizeof um) {
+			glibtop_warn_io_r (server, "kvm_read (ufsmount)");
+			return;
+		}
+
+		if (kvm_read(server->machine->kd, (gulong)cdev2priv(um.um_dev), &priv, sizeof priv) != sizeof priv) {
+			glibtop_warn_io_r (server, "kvm_read (priv)");
+			return;
+		}
+
+		*dev = priv.cdp_inode;
+
+#else /* older versions */
 #if (__FreeBSD_version >= 800039) || (__FreeBSD_kernel_version >= 800039)
-        if (kvm_read (server->machine.kd, (gulong) cdev2priv(inode.i_dev), (char *) &priv,
+        if (kvm_read (server->machine->kd, (gulong) cdev2priv(inode.i_dev), (char *) &priv,
 		      sizeof (priv))
 #else
-        if (kvm_read (server->machine.kd, (gulong) inode.i_dev, (char *) &si,
+        if (kvm_read (server->machine->kd, (gulong) inode.i_dev, (char *) &si,
 	              sizeof (si)) != sizeof (si) ||
-            kvm_read (server->machine.kd, (gulong) si.si_priv, (char *) &priv,
+            kvm_read (server->machine->kd, (gulong) si.si_priv, (char *) &priv,
 		      sizeof (priv))
 #endif
 	    != sizeof (priv))
@@ -182,6 +217,8 @@ _glibtop_sysdeps_freebsd_dev_inode (glibtop *server, struct vnode *vnode,
         }
 
         *dev = (guint64) priv.cdp_inode;
+#endif /* older versions */
+
 	    } /* end-if IS_UFS */
 }
 #endif
@@ -209,8 +246,6 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
         int count;
         int update = 0;
 
-        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MAP), 0);
-
         memset (buf, 0, sizeof (glibtop_proc_map));
 
         /* It does not work for the swapper task. */
@@ -221,7 +256,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
         glibtop_suid_enter (server);
 
         /* Get the process data */
-        pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
+        pinfo = kvm_getprocs (server->machine->kd, KERN_PROC_PID, pid, &count);
         if ((pinfo == NULL) || (count < 1)) {
                 glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
 		glibtop_suid_leave (server);
@@ -230,7 +265,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
         /* Now we get the memory maps. */
 
-        if (kvm_read (server->machine.kd,
+        if (kvm_read (server->machine->kd,
                         (gulong) pinfo [0].ki_vmspace,
                         (char *) &vmspace, sizeof (vmspace)) != sizeof (vmspace)) {
                 glibtop_warn_io_r (server, "kvm_read (vmspace)");
@@ -240,7 +275,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
         first = vmspace.vm_map.header.next;
 
-        if (kvm_read (server->machine.kd,
+        if (kvm_read (server->machine->kd,
                         (gulong) vmspace.vm_map.header.next,
                         (char *) &entry, sizeof (entry)) != sizeof (entry)) {
                 glibtop_warn_io_r (server, "kvm_read (entry)");
@@ -263,7 +298,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
                 guint len;
 
                 if (update) {
-                        if (kvm_read (server->machine.kd,
+                        if (kvm_read (server->machine->kd,
                                         (gulong) entry.next,
                                         (char *) &entry, sizeof (entry)) != sizeof (entry)) {
                                 glibtop_warn_io_r (server, "kvm_read (entry)");
@@ -281,7 +316,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
                 /* We're only interested in `vm_object's */
 
-                if (kvm_read (server->machine.kd,
+                if (kvm_read (server->machine->kd,
                                 (gulong) entry.object.vm_object,
                                 (char *) &object, sizeof (object)) != sizeof (object)) {
                         glibtop_warn_io_r (server, "kvm_read (object)");
@@ -296,7 +331,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
                 if (!object.handle)
                         continue;
 
-                if (kvm_read (server->machine.kd,
+                if (kvm_read (server->machine->kd,
                                 (gulong) object.handle,
                                 (char *) &vnode, sizeof (vnode)) != sizeof (vnode)) {
                         glibtop_warn_io_r (server, "kvm_read (vnode)");
